/*
	sample2d.c : sample program of ELview-2d

	usage :
	> cl sample2d.c ev_c.lib
	> sample2d
	> ev2
*/

#include <stdio.h>
#include <stdlib.h>
#include "ev_c.h"

int main(void)
{
	int i, j, n, ndiv, nx, ny;
	double px[3], py[3], x1, y1, x2, y2, *f, fmin, fmax;
	unsigned char r[3], g[3], b[3];
	char str[100];
	const double w = 300, h = 200;

	// === page 1 ===

	startPage(w, h);

	// line
	drawLine(10, 20, 140, 20);
	setColorNo(20);
	drawLine(10, 30, 140, 30);

	// characters
	setColorNo(1);
	drawString(10, 80, 10, "sample-2d {");
	setColorNo(0);
	drawString(10, 60,  7, "ABCDEFGHIJKLMNOPQRSTUVWXYZ");
	drawString(10, 50,  7, "abcdefghijklmnopqrstuvwxyz");
	drawString(10, 40,  7, "0123456789");

	// flat shading
	px[0] =  10; px[1] =  90; px[2] =  50;
	py[0] = 120; py[1] = 120; py[2] = 180;
	setColor(0, 255, 0);
	fillPolygon(3, px, py);

	// smooth shading (vertex shading)
	px[0] = 110; px[1] = 190; px[2] = 150;
	py[0] = 120; py[1] = 120; py[2] = 180;
	r[0] = 255; r[1] =   0; r[2] =   0;
	g[0] =   0; g[1] = 255; g[2] =   0;
	b[0] =   0; b[1] =   0; b[2] = 255;
	gradPolygon(3, px, py, r, g, b);

	// wire
	px[0] = 210; px[1] = 290; px[2] = 250;
	py[0] = 120; py[1] = 120; py[2] = 180;
	setColor(0, 0, 255);
	drawPolygon(3, px, py);

	// ellipse
	setColorNo(17);
	drawEllipse(180, 10, 270, 100);
	setColorNo(3);
	fillEllipse(200, 20, 250,  90);

	// === page 2 ===

	startPage(w, h);

	// y = f(x)
	x1 = 20; y1 = 100, x2 = 140; y2 = 180;
	evGrid(x1, y1, x2, y2, 10, 6);
	ndiv = 100;
	f = malloc((ndiv+1)*sizeof(double));
	for (n = 0; n <= ndiv; n++) {
		f[n] = 1 - ((double)n/ndiv)*((double)n/ndiv);
	}
	fmin = 0;
	fmax = 1;
	evFunc1(ndiv, f, fmin, fmax, x1, y1, x2, y2);

	// arrow
	evArrow(x1+20, y1-10, x1+40, y1-10);

	// contour : z = f(x,y)
	nx = 30;
	ny = 20;
	f = malloc((nx+1)*(ny+1)*sizeof(double));
	fmin = 0;
	fmax = (nx*nx + ny*ny) / 4;
	for (i = 0; i <= nx; i++) {
		for (j = 0; j <= ny; j++) {
			f[i*(ny+1)+j] = fmax - ((i-nx/2.0)*(i-nx/2.0) + (j-ny/2.0)*(j-ny/2.0));
		}
	}
	evContour1(nx, ny, f, fmin, fmax, 0, 170,   5, 290,  45);
	evContour1(nx, ny, f, fmin, fmax, 2, 170,  55, 290,  95);
	evContour1(nx, ny, f, fmin, fmax, 4, 170, 105, 290, 145);
	evContour1(nx, ny, f, fmin, fmax, 6, 170, 155, 290, 195);

	// color sample
	evColors(10, 20, 160, 40, 1, 0);
	for (n = 1; n <= 20; n++) {
		sprintf(str, "%d", n);
		drawString(3+7.5*n, 14, 5, str);
	}

	return 0;
}
